@@ -1,23 +1,42 @@
+import os
 import re
 import yaml
 import deepmerge
+import jsonschema
 from pathlib import Path
 from copy import deepcopy
 from frictionless import File
 from .system import system
+from .exception import LivemarkException
 from .helpers import cached_property
 from . import settings
 from . import helpers
 
 
 class Document:
-    def __init__(self, source, *, target=None, format=None, project=None):
+    def __init__(self, source, *, target=None, format=None, project=None, create=False):
+
+        # Create plugins
+        plugins = []
+        for Plugin in system.Plugins:
+            plugins.append(Plugin(self))
+
+        # Create source
+        if create and source == settings.DEFAULT_SOURCE:
+            if not os.path.exists(source):
+                with open(source, "w"):
+                    pass
 
         # Infer target
         if not target:
             suffix = f".{format or settings.DEFAULT_FORMAT}"
             target = str(Path(source).with_suffix(suffix))
 
+        # Infer format
+        if not format:
+            file = File(target)
+            format = file.format
+
         # Read input
         with open(source) as file:
             input = file.read()
@@ -37,18 +56,13 @@ class Document:
         # Save attributes
         self.__source = source
         self.__target = target
+        self.__format = format
         self.__project = project
         self.__preface = preface
         self.__config = config
         self.__input = input
         self.__output = None
-
-        # Create plugins (document needs to be ready)
-        self.__plugins = system.create_plugins(self)
-
-    @property
-    def plugins(self):
-        return self.__plugins
+        self.__plugins = plugins
 
     @property
     def source(self):
@@ -67,14 +81,6 @@ class Document:
     def project(self):
         return self.__project
 
-    @property
-    def preface(self):
-        return self.__preface
-
-    @property
-    def config(self):
-        return self.__config
-
     @property
     def input(self):
         return self.__input
@@ -91,6 +97,18 @@ class Document:
     def output(self, value):
         self.__output = value
 
+    @property
+    def preface(self):
+        return self.__preface
+
+    @property
+    def config(self):
+        return self.__config
+
+    @property
+    def plugins(self):
+        return self.__plugins
+
     @cached_property
     def title(self):
         prefix = "# "
@@ -113,6 +131,19 @@ class Document:
     # Process
 
     def process(self):
+
+        # Process config
+        for plugin in self.plugins:
+            self.config.setdefault(plugin.name, {})
+            if not isinstance(self.config[plugin.name], dict):
+                self.config[plugin.name] = {"self": self.config[plugin.name]}
+            plugin.process_config(self.config)
+            if self.config[plugin.name] and plugin.profile:
+                validator = jsonschema.Draft7Validator(plugin.profile)
+                for error in validator.iter_errors(self.config[plugin.name]):
+                    raise LivemarkException(f'Plugin "{plugin.name}" error: {error}')
+
+        # Process document
         for plugin in self.plugins:
             plugin.process_document(self)
 
